#let HAVE_LIBEV = true
#let HAVE_PTHREAD = true
#let HAVE_EVENTFD = false
#let HAVE_FD_PASSING = true
#let HAVE_GETCPU = false
#let HAVE_AFFINITY = false
#let HAVE_GET_CREDENTIALS_LINUX = false
#let HAVE_GET_CREDENTIALS_NETBSD = false
#let HAVE_GET_CREDENTIALS_OPENBSD = true
#let HAVE_GET_CREDENTIALS_FREEBSD = false
#let HAVE_GETPEEREID = true
#let HAVE_FDATASYNC = true
#let HAVE_NETDB_REENTRANT = false
#let HAVE_GET_CREDENTIALS = HAVE_GET_CREDENTIALS_LINUX || HAVE_GET_CREDENTIALS_NETBSD || HAVE_GET_CREDENTIALS_OPENBSD || HAVE_GET_CREDENTIALS_FREEBSD || HAVE_GETPEEREID
#let windows=false
#let android=false
#let libev_default=false
